"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEFAULT_NG_COMPILER_OPTIONS = void 0;
exports.setupCompilation = setupCompilation;
exports.styleTransform = styleTransform;
const tslib_1 = require("tslib");
const ts = tslib_1.__importStar(require("typescript"));
const sass_embedded_1 = require("sass-embedded");
const augments_1 = require("./augments");
const utils_1 = require("../utils");
const component_stylesheets_1 = require("@angular/build/src/tools/esbuild/angular/component-stylesheets");
const targets_from_browsers_1 = require("../utils/targets-from-browsers");
const private_1 = require("@angular/build/private");
exports.DEFAULT_NG_COMPILER_OPTIONS = {
    suppressOutputPathCheck: true,
    outDir: undefined,
    sourceMap: true,
    declaration: false,
    declarationMap: false,
    allowEmptyCodegenFiles: false,
    annotationsAs: 'decorators',
    enableResourceInlining: false,
    noEmitOnError: false,
    mapRoot: undefined,
    sourceRoot: undefined,
    supportTestBed: false,
    supportJitMode: false,
};
async function setupCompilation(config, options) {
    const isProd = config.mode === 'production';
    const { readConfiguration } = await (0, utils_1.loadCompilerCli)();
    const { options: tsCompilerOptions, rootNames } = readConfiguration(config.source?.tsconfigPath ?? options.tsConfig, {
        ...exports.DEFAULT_NG_COMPILER_OPTIONS,
        ...(options.useTsProjectReferences
            ? {
                sourceMap: false,
                inlineSources: false,
                isolatedModules: true,
            }
            : {}),
    });
    const compilerOptions = tsCompilerOptions;
    const host = ts.createIncrementalCompilerHost(compilerOptions);
    const componentStylesheetBundler = new component_stylesheets_1.ComponentStylesheetBundler({
        workspaceRoot: options.root,
        optimization: config.mode === 'production',
        cacheOptions: { path: '', basePath: '', enabled: false },
        inlineFonts: false,
        outputNames: {
            bundles: config.mode === 'production' ? '[name]-[hash]' : '[name]',
            media: `media/${config.mode === 'production' ? '[name]-[hash]' : '[name]'}`,
        },
        sourcemap: false,
        target: (0, targets_from_browsers_1.transformSupportedBrowsersToTargets)((0, private_1.getSupportedBrowsers)(options.root, {
            warn: (message) => console.warn(message),
        })),
    }, options.inlineStyleLanguage, false);
    if (options.aot) {
        (0, augments_1.augmentHostWithResources)(host, (code) => (0, sass_embedded_1.compileString)(code).css, {
            inlineStylesExtension: options.inlineStyleLanguage,
            isProd,
        });
    }
    return {
        rootNames,
        compilerOptions,
        host,
        componentStylesheetBundler,
    };
}
function styleTransform(componentStylesheetBundler) {
    return async (styles, containingFile, stylesheetFile) => {
        try {
            let stylesheetResult;
            if (stylesheetFile) {
                stylesheetResult = await componentStylesheetBundler.bundleFile(stylesheetFile);
            }
            else {
                stylesheetResult = await componentStylesheetBundler.bundleInline(styles, containingFile, containingFile.endsWith('.html') ? 'css' : undefined);
            }
            return stylesheetResult.contents;
        }
        catch (e) {
            console.error('Failed to compile styles. Continuing execution ignoring failing stylesheet...', e);
            return '';
        }
    };
}
