"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupCompilationWithParallelCompilation = setupCompilationWithParallelCompilation;
const parallel_compilation_1 = require("@angular/build/src/tools/angular/compilation/parallel-compilation");
const core_1 = require("@swc/core");
const setup_compilation_1 = require("./setup-compilation");
async function setupCompilationWithParallelCompilation(config, options) {
    const { rootNames, compilerOptions, componentStylesheetBundler } = await (0, setup_compilation_1.setupCompilation)(config, options);
    const parallelCompilation = new parallel_compilation_1.ParallelCompilation(!options.aot, options.hasServer === false);
    const fileReplacements = options.fileReplacements.reduce((r, f) => {
        r[f.replace] = f.with;
        return r;
    }, {});
    try {
        await parallelCompilation.initialize(config.source?.tsconfigPath ?? options.tsConfig, {
            ...compilerOptions,
            fileReplacements,
            modifiedFiles: new Set(rootNames),
            transformStylesheet: (0, setup_compilation_1.styleTransform)(componentStylesheetBundler),
            processWebWorker(workerFile) {
                return (0, core_1.transformFileSync)(workerFile).code;
            },
        }, () => compilerOptions);
    }
    catch (e) {
        console.error('Failed to initialize Angular Compilation', e);
    }
    return parallelCompilation;
}
