"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.maxWorkers = exports.isUsingWindows = void 0;
exports.getTextByProperty = getTextByProperty;
exports.getAllTextByProperty = getAllTextByProperty;
exports.normalizeQuotes = normalizeQuotes;
exports.isPresent = isPresent;
exports.parseMaxWorkers = parseMaxWorkers;
const node_os_1 = require("node:os");
const constants_1 = require("./constants");
const isUsingWindows = () => (0, node_os_1.platform)() === 'win32';
exports.isUsingWindows = isUsingWindows;
function getTextByProperty(name, properties) {
    return properties
        .filter((property) => property.getName() === name)
        .map((property) => normalizeQuotes(property.getInitializer()?.getText()))
        .filter((url) => url !== undefined);
}
function getAllTextByProperty(name, properties) {
    return properties
        .filter((property) => property.getName() === name)
        .map((property) => property.getInitializer())
        .flatMap((array) => array.getElements().map((el) => normalizeQuotes(el.getText())));
}
function normalizeQuotes(str) {
    return str ? str.replace(/['"`]/g, '') : str;
}
function isPresent(variable) {
    return typeof variable === 'string' && variable.trim() !== '';
}
function parseMaxWorkers(value) {
    if (!isPresent(value))
        return null;
    const parsed = Number(value);
    return Number.isNaN(parsed) || parsed <= 0 ? null : parsed; // Ensure valid positive number
}
const maxWorkers = () => {
    const parsedWorkers = parseMaxWorkers(process.env[constants_1.ENV_NG_BUILD_MAX_WORKERS]);
    return parsedWorkers !== null
        ? parsedWorkers
        : Math.min(4, Math.max((0, node_os_1.availableParallelism)() - 1, 1));
};
exports.maxWorkers = maxWorkers;
